=======
hep_spt
=======

.. image:: https://img.shields.io/travis/rust-lang/rust.svg
   :target: https://travis-ci.org/mramospe/hep_spt

.. image:: https://img.shields.io/badge/documentation-link-blue.svg
   :target: https://mramospe.github.io/hep_spt/

.. inclusion-marker-do-not-remove

The **High Energy Physics Statistics and Plotting Tools** package provides tools to work in **High Energy Physics** using general python packages.

Main points
===========

  * Statistical functions to work with Bayesian/Frequentist approaches.
  * Utilities to handle poissonian and/or weighted histograms.
  * Tools to handle `matplotlib <https://matplotlib.org/>`_ figures.

Considerations:
===============

  * This package makes use of `numpy <http://www.numpy.org/>`_ and `pandas <https://pandas.pydata.org/>`_.
  * Samples are usually preferred as structured `numpy.ndarray <https://docs.scipy.org/doc/numpy-1.13.0/reference/generated/numpy.ndarray.html>`_ or `pandas.DataFrame <https://pandas.pydata.org/pandas-docs/stable/generated/pandas.DataFrame.html>`_ objects.
  * Plotting functions and classes are designed to work with `matplotlib <https://matplotlib.org/>`_.
  * Statistical tools are built on top of the standard `scipy <https://www.scipy.org/>`_ package.

Installation:
=============

This package is available on PyPi, so just type:

.. code-block:: bash

   pip install hep-spt

To use the **latest development version**, clone the repository and install with `pip`:

.. code-block:: bash

   git clone https://github.com/mramospe/hep_spt.git
   cd hep_spt
   sudo pip install .
